@@ -82,6 +82,8 @@ public:
     QString windowManagerNameString() const;
     WMName windowManagerName() const;
 
+    QVector<quint32> allWindowIdList() const;
+    QVector<quint32> currentWorkspaceWindowIdList() const;
     QList<DForeignWindow*> currentWorkspaceWindows() const;
 
 Q_SIGNALS:
