@@ -312,8 +312,13 @@ bool DApplicationPrivate::isUserManualExists()
  * \~chinese - 在 FORCE_RASTER_WIDGETS 宏生效的情况下，默认设置 Qt::AA_ForceRasterWidgets 以减少 glx 相关库的加载，减少程序启动时间；
  * \~chinese - 自动根据 applicationName 和 系统 locale 加载对应的翻译文件；
  * \~chinese - 会根据系统gsettings中 com.deepin.dde.dapplication 的 qpixmapCacheLimit 值来设置 QPixmapCache::cacheLimit ；
+ * \~chinese - 会根据系统gsettings中 com.deepin.dde.touchscreen longpress-duration 的值来设置 QTapAndHoldGesture::timeout ；
  * \~chinese - 方便地通过 setSingleInstance 来实现程序的单实例。
  *
+ * \~chinese \note DApplication 设置的 QTapAndHoldGesture::timeout 会比 gsettings
+ * \~chinese 中的值小 100，用来绕过 Dock 长按松开容易导致应用启动的问题，详细解释见
+ * \~chinese 见代码注释或者 https://github.com/linuxdeepin/internal-discussion/issues/430
+ *
  * \~chinese \sa loadTranslator, setSingleInstance.
  */
 
@@ -367,6 +372,26 @@ DApplication::DApplication(int &argc, char **argv) :
         if (gsettings.keys().contains("qpixmapCacheLimit"))
             QPixmapCache::setCacheLimit(gsettings.get("qpixmap-cache-limit").toInt());
     }
+
+    // set QTapAndHoldGesture::timeout
+    if (QGSettings::isSchemaInstalled("com.deepin.dde.touchscreen")) {
+        QGSettings gsettings("com.deepin.dde.touchscreen");
+        if (gsettings.keys().contains("longpressDuration"))
+            // NOTE(hualet): -100 is a workaround against the situation that that sometimes longpress
+            // and release on Dock cause App launches which should be avoided.
+            //
+            // I guess it happens like this: longpress happens on Dock,
+            // Dock menu shows(doesn't grab the mouse which is a bug can't be fixed easily),
+            // user ends the longpress, DDE Dock recevies mouseReleaseEvent and checks for
+            // QTapAndHoldGesture  which is still not happening (maybe because the timer used is
+            // a CoarseTimer?), so Dock treats the event as a normal mouseReleaseEvent, launches the
+            // App or triggers the action.
+            //
+            // see: https://github.com/linuxdeepin/internal-discussion/issues/430
+            //
+            // This workaround hopefully can fix most of this situations.
+            QTapAndHoldGesture::setTimeout(gsettings.get("longpress-duration").toInt() - 100);
+    }
 #endif
 }
 
