@@ -44,32 +44,23 @@ class LIBDTKWIDGETSHARED_EXPORT DBlurEffectWidget : public QWidget, public DTK_C
 
 public:
     // TODO: To support MeanBlur, MedianBlur, BilateralFilter
-    /*!
-     * \brief The BlurMode enum determines which blur algorithm will be used.
-     */
     enum BlurMode {
-        GaussianBlur /*!< gaussian blur */
+        GaussianBlur
     };
 
     Q_ENUMS(BlurMode)
 
-    /*!
-     * \brief The BlendMode enum controls with which part the widget will be blended with.
-     */
     enum BlendMode {
-        InWindowBlend, /*!< blend with the widgets between the window and this widget */
-        BehindWindowBlend /*!< blend with the pixels behind the window */
+        InWindowBlend,
+        BehindWindowBlend
     };
 
     Q_ENUMS(BlendMode)
 
-    /*!
-     * \brief The MaskColorType enum contains the possible color used as the background.
-     */
     enum MaskColorType {
-        DarkColor, /*!< dark style, predefined dark color is used */
-        LightColor, /*!< light style, predefined light color is used */
-        CustomColor /*!< custom color, custom color is used */
+        DarkColor,
+        LightColor,
+        CustomColor
     };
 
     Q_ENUMS(MaskColorType)
